@@ -51,7 +51,7 @@ class ResmokeProxy:
             cmd = self.resmoke_cmd
             cmd.append("multiversion-config")
             try:
-                result = subprocess.run(cmd, capture_output=True, check=True)
+                result = subprocess.run(cmd, capture_output=True, check=True, shell=True)
             except subprocess.CalledProcessError:
                 LOGGER.error("Error invoking resmoke", exc_info=True)
                 LOGGER.error(
